Index: /applications/editors/josm/plugins/validator/src/org/openstreetmap/josm/plugins/validator/tests/UntaggedWay.java
===================================================================
--- /applications/editors/josm/plugins/validator/src/org/openstreetmap/josm/plugins/validator/tests/UntaggedWay.java	(revision 3258)
+++ /applications/editors/josm/plugins/validator/src/org/openstreetmap/josm/plugins/validator/tests/UntaggedWay.java	(revision 3259)
@@ -3,5 +3,5 @@
 import static org.openstreetmap.josm.tools.I18n.tr;
 
-import java.util.Map;
+import java.util.*;
 
 import org.openstreetmap.josm.data.osm.Way;
@@ -14,7 +14,20 @@
 public class UntaggedWay extends Test 
 {
-	/** Tags allowed in a way */
-	public static String[] allowedTags = new String[] { "created_by", "converted_by" };
-	
+    /** Tags allowed in a way */
+    public static final String[] ALLOWED_TAGS = new String[] { "created_by", "converted_by" };
+
+    /** Ways that must have a name */
+    public static final Set<String> NAMED_WAYS = new HashSet<String>();
+    static
+    {
+        NAMED_WAYS.add( "motorway" ); 
+        NAMED_WAYS.add( "trunk" ); 
+        NAMED_WAYS.add( "primary" ); 
+        NAMED_WAYS.add( "secondary" ); 
+        NAMED_WAYS.add( "tertiary" ); 
+        NAMED_WAYS.add( "residential" ); 
+        NAMED_WAYS.add( "pedestrian" ); ;
+    }
+    
     /**
 	 * Constructor
@@ -34,8 +47,9 @@
 		{
 			numTags = tags.size();
-			for( String tag : allowedTags)
+			for( String tag : ALLOWED_TAGS)
 				if( tags.containsKey(tag) ) numTags--;
             
-            if( numTags != 0 && tags.containsKey("highway" ) )
+            String highway = tags.get("highway");
+            if( numTags != 0 && highway != null && NAMED_WAYS.contains(highway))
             {
                 if( !tags.containsKey("name") && !tags.containsKey("ref") )
